@@ -19,17 +19,7 @@ class Thermometer(Device):
     uncached : bool:
         (Default value = False)
         If True forces owserver to query the 1wire bus on each property access.
-
-    lower_precision : int, optional:
-        The lower precision allowed for temperature readings.
-
-    upper_precision : int, optional:
-        The upper precision allowed for temperature readings.
     """
-    def __repr__(self):
-        super_repr = super().__repr__().replace(')>', ',')
-        return (f'{super_repr} temperature={self.temperature})>')
-
     @property
     def temperature(self) -> float:
         """
